<?php
/**
 * Plugin Name:  BdP Kompass
 * Description: Wordpress-Plugin zur Unterstützung von Stämmen im Bund der Pfadfinderinnen und Pfadfinder e.V. zur optimalen Verwaltung eurer Webseite
 * Version: 4.3.9
 * Tags: bdp, utility, helper
 * Requires at least: 6.0
 * Requires PHP: 8.2
 * Author: Thomas Günther
 * Author URI: https://www.sachsen.pfadfinden.de
 * Update URI: http://lv-sachsen-main.bdp.mein-verein.online/wordpress/
 * Text Domain: bdp-kompass
 */

use Bdp\Modules\EventParticipants\Controllers\MainController as EventsMain;
use Bdp\Modules\Gruppen\Controllers\MainController as GruppenMain;
use Bdp\Modules\KompassSettings\Controllers\SettingsPage as KomnpassSettings;
use Bdp\Modules\LimitLoginAttempts\Controllers\OptionsPage as OptionsPageAlias;
use Bdp\Modules\Mail\Controllers\MailController;
use Bdp\Modules\Security\Security;
use Bdp\Modules\Seo\Seo;

require_once dirname(__FILE__) . '/includes/setup.php';

function bdp_plugin_install() {

}


function bdp_plugin_init() {
	bdp_kompass_load_plugin_textdomain();
	Security::ProhibitBots();
	Security::SetPageFilters();
	EventsMain::setup();

	if (null == get_option('kompass_already_installed', null)) {
		Seo::setup();
		Calendar::setup();
		Security::setup();
		update_option('kompass_already_installed', true);
		wp_redirect( 'site-health.php?tab=bdp_enhanced_security');
	}
	Seo::importVerificationKeys();

}

add_action('admin_menu', function () {
	bdp_kompass_load_plugin_textdomain();
	new OptionsPageAlias();
	new KomnpassSettings();
	new EventsMain();
	new MailController();



});
add_action('wp_ajax_kompass_show_ajax', 'kompass_load_ajax_content');
add_action('wp_ajax_nopriv_kompass_show_ajax', 'kompass_load_ajax_content');

function register_custom_theme_directory() {
    $file = ABSPATH . '/wp-content/plugins/bdp-kompass/buena/' ;

    system('mkdir ' . ABSPATH . 'wp-content/themes/buena/');
    system('cp -r ' . $file . '* ' . ABSPATH . 'wp-content/themes/buena/');

    switch_theme('buena');
}

function enqueue_custom_password_js() {
	wp_enqueue_script( 'kompass-ajax', BDP_LV_PLUGIN_URL . '/assets/ajax.js');
	wp_enqueue_script( 'searchable-table', BDP_LV_PLUGIN_URL . '/assets/searchtable.js');
    wp_enqueue_script( 'custom-password-js', BDP_LV_PLUGIN_URL . 'assets/password.js');
	wp_localize_script( 'custom-password-js', 'php_vars', [
		'allowed_strengths' => kompass_get_minimal_password_strength(),
		'password_too_short_text' => 'Dass Passwort entspricht nicht den Anforderungen.'
	]);
}


add_action( 'after_setup_theme', 'kompass_after_setup_theme' );
